
/* Generated data (by glib-mkenums) */

#if !defined(ST_H_INSIDE) && !defined(ST_COMPILATION)
#error "Only <st/st.h> can be included directly.h"
#endif

#ifndef __ST_ENUM_TYPES_H__
#define __ST_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./st/st-button.h" */
GType st_button_mask_get_type (void) G_GNUC_CONST;
#define ST_TYPE_BUTTON_MASK (st_button_mask_get_type())

/* enumerations from "./st/st-table.h" */
GType st_table_child_options_get_type (void) G_GNUC_CONST;
#define ST_TYPE_TABLE_CHILD_OPTIONS (st_table_child_options_get_type())

/* enumerations from "./st/st-texture-cache.h" */
GType st_texture_cache_policy_get_type (void) G_GNUC_CONST;
#define ST_TYPE_TEXTURE_CACHE_POLICY (st_texture_cache_policy_get_type())

/* enumerations from "./st/st-theme-node.h" */
GType st_side_get_type (void) G_GNUC_CONST;
#define ST_TYPE_SIDE (st_side_get_type())

GType st_corner_get_type (void) G_GNUC_CONST;
#define ST_TYPE_CORNER (st_corner_get_type())

GType st_text_decoration_get_type (void) G_GNUC_CONST;
#define ST_TYPE_TEXT_DECORATION (st_text_decoration_get_type())

GType st_text_align_get_type (void) G_GNUC_CONST;
#define ST_TYPE_TEXT_ALIGN (st_text_align_get_type())

GType st_gradient_type_get_type (void) G_GNUC_CONST;
#define ST_TYPE_GRADIENT_TYPE (st_gradient_type_get_type())

/* enumerations from "./st/st-types.h" */
GType st_align_get_type (void) G_GNUC_CONST;
#define ST_TYPE_ALIGN (st_align_get_type())

GType st_icon_type_get_type (void) G_GNUC_CONST;
#define ST_TYPE_ICON_TYPE (st_icon_type_get_type())

GType st_background_size_get_type (void) G_GNUC_CONST;
#define ST_TYPE_BACKGROUND_SIZE (st_background_size_get_type())

G_END_DECLS

#endif /* !__ST_ENUM_TYPES_H__ */

/* Generated data ends here */

